2021-01-20 Version: 2.0.2
- AMP Version Change.

2021-01-20 Version: 2.0.1
- AMP Version Change.

2020-12-30 Version: 2.0.0
- AMP Version Change.

2020-12-30 Version: 2.0.0
- AMP Version Change.

2020-12-17 Version: 1.2.0
- Support template version.
- Support to share template.
- Stack and StackGroup support TemplateId and TemplateVersion.
- Add GenerateTemplatePolicy which can generate RAM policy by template.

